==> zio-aws-sfn_2.12-7.28.29.6-sources.jar: zio/aws/sfn/model/package.scala <==
package zio.aws.sfn
import zio.prelude.Subtype
import zio.aws.sfn.model.primitives.TagKey
import java.time.Instant
import zio.aws.sfn.model.primitives.LongArn.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AliasDescription extends zio.prelude.Subtype[String]
    type AliasDescription = zio.aws.sfn.model.primitives.AliasDescription.Type
    object Arn extends zio.prelude.Subtype[String]
    type Arn = zio.aws.sfn.model.primitives.Arn.Type
    object BilledDuration extends zio.prelude.Subtype[Long]
    type BilledDuration = zio.aws.sfn.model.primitives.BilledDuration.Type
    object BilledMemoryUsed extends zio.prelude.Subtype[Long]
    type BilledMemoryUsed = zio.aws.sfn.model.primitives.BilledMemoryUsed.Type
    object CharacterRestrictedName extends zio.prelude.Subtype[String]
    type CharacterRestrictedName =
      zio.aws.sfn.model.primitives.CharacterRestrictedName.Type
    object ClientToken extends zio.prelude.Subtype[String]
    type ClientToken = zio.aws.sfn.model.primitives.ClientToken.Type
    object ConnectorParameters extends zio.prelude.Subtype[String]
    type ConnectorParameters =
      zio.aws.sfn.model.primitives.ConnectorParameters.Type
    object Definition extends zio.prelude.Subtype[String]
    type Definition = zio.aws.sfn.model.primitives.Definition.Type
    object Enabled extends zio.prelude.Subtype[Boolean]
    type Enabled = zio.aws.sfn.model.primitives.Enabled.Type
    object EventId extends zio.prelude.Subtype[Long]
    type EventId = zio.aws.sfn.model.primitives.EventId.Type
    object HTTPBody extends zio.prelude.Subtype[String]
    type HTTPBody = zio.aws.sfn.model.primitives.HTTPBody.Type
    object HTTPHeaders extends zio.prelude.Subtype[String]
    type HTTPHeaders = zio.aws.sfn.model.primitives.HTTPHeaders.Type
    object HTTPMethod extends zio.prelude.Subtype[String]
    type HTTPMethod = zio.aws.sfn.model.primitives.HTTPMethod.Type
    object HTTPProtocol extends zio.prelude.Subtype[String]
    type HTTPProtocol = zio.aws.sfn.model.primitives.HTTPProtocol.Type
    object HTTPStatusCode extends zio.prelude.Subtype[String]
    type HTTPStatusCode = zio.aws.sfn.model.primitives.HTTPStatusCode.Type
    object HTTPStatusMessage extends zio.prelude.Subtype[String]
    type HTTPStatusMessage = zio.aws.sfn.model.primitives.HTTPStatusMessage.Type
    object Identity extends zio.prelude.Subtype[String]
    type Identity = zio.aws.sfn.model.primitives.Identity.Type
    object IncludeExecutionData extends zio.prelude.Subtype[Boolean]
    type IncludeExecutionData =
      zio.aws.sfn.model.primitives.IncludeExecutionData.Type
    object IncludeExecutionDataGetExecutionHistory
        extends zio.prelude.Subtype[Boolean]
    type IncludeExecutionDataGetExecutionHistory =
      zio.aws.sfn.model.primitives.IncludeExecutionDataGetExecutionHistory.Type
    object IncludedDetails extends zio.prelude.Subtype[Boolean]
    type IncludedDetails = zio.aws.sfn.model.primitives.IncludedDetails.Type
    object KmsDataKeyReusePeriodSeconds extends zio.prelude.Subtype[Int]
    type KmsDataKeyReusePeriodSeconds =
      zio.aws.sfn.model.primitives.KmsDataKeyReusePeriodSeconds.Type
    object KmsKeyId extends zio.prelude.Subtype[String]
    type KmsKeyId = zio.aws.sfn.model.primitives.KmsKeyId.Type
    object ListExecutionsPageToken extends zio.prelude.Subtype[String]
    type ListExecutionsPageToken =
      zio.aws.sfn.model.primitives.ListExecutionsPageToken.Type
    object LongArn extends zio.prelude.Subtype[String]
    type LongArn = zio.aws.sfn.model.primitives.LongArn.Type
    type LongObject = Long
    object MapRunLabel extends zio.prelude.Subtype[String]
    type MapRunLabel = zio.aws.sfn.model.primitives.MapRunLabel.Type
    object MaxConcurrency extends zio.prelude.Subtype[Int]
    type MaxConcurrency = zio.aws.sfn.model.primitives.MaxConcurrency.Type
    object Name extends zio.prelude.Subtype[String]
    type Name = zio.aws.sfn.model.primitives.Name.Type
    object PageSize extends zio.prelude.Subtype[Int]
    type PageSize = zio.aws.sfn.model.primitives.PageSize.Type
    object PageToken extends zio.prelude.Subtype[String]
    type PageToken = zio.aws.sfn.model.primitives.PageToken.Type
    object Publish extends zio.prelude.Subtype[Boolean]
    type Publish = zio.aws.sfn.model.primitives.Publish.Type
    object RedriveCount extends zio.prelude.Subtype[Int]
    type RedriveCount = zio.aws.sfn.model.primitives.RedriveCount.Type
    object RevealSecrets extends zio.prelude.Subtype[Boolean]
    type RevealSecrets = zio.aws.sfn.model.primitives.RevealSecrets.Type
    object ReverseOrder extends zio.prelude.Subtype[Boolean]
    type ReverseOrder = zio.aws.sfn.model.primitives.ReverseOrder.Type
    object RevisionId extends zio.prelude.Subtype[String]
    type RevisionId = zio.aws.sfn.model.primitives.RevisionId.Type
    object SensitiveCause extends zio.prelude.Subtype[String]
    type SensitiveCause = zio.aws.sfn.model.primitives.SensitiveCause.Type
    object SensitiveData extends zio.prelude.Subtype[String]
    type SensitiveData = zio.aws.sfn.model.primitives.SensitiveData.Type
    object SensitiveDataJobInput extends zio.prelude.Subtype[String]
    type SensitiveDataJobInput =
      zio.aws.sfn.model.primitives.SensitiveDataJobInput.Type
    object SensitiveError extends zio.prelude.Subtype[String]
    type SensitiveError = zio.aws.sfn.model.primitives.SensitiveError.Type
    object StateName extends zio.prelude.Subtype[String]
    type StateName = zio.aws.sfn.model.primitives.StateName.Type
    object TagKey extends zio.prelude.Subtype[String]
    type TagKey = zio.aws.sfn.model.primitives.TagKey.Type
    object TagValue extends zio.prelude.Subtype[String]
    type TagValue = zio.aws.sfn.model.primitives.TagValue.Type
    object TaskToken extends zio.prelude.Subtype[String]
    type TaskToken = zio.aws.sfn.model.primitives.TaskToken.Type
    object TimeoutInSeconds extends zio.prelude.Subtype[Long]
    type TimeoutInSeconds = zio.aws.sfn.model.primitives.TimeoutInSeconds.Type
    object Timestamp extends zio.prelude.Subtype[Instant]
    type Timestamp = zio.aws.sfn.model.primitives.Timestamp.Type
    object ToleratedFailureCount extends zio.prelude.Subtype[Long]
    type ToleratedFailureCount =
      zio.aws.sfn.model.primitives.ToleratedFailureCount.Type
    object ToleratedFailurePercentage extends zio.prelude.Subtype[Float]
    type ToleratedFailurePercentage =
      zio.aws.sfn.model.primitives.ToleratedFailurePercentage.Type
    object TraceHeader extends zio.prelude.Subtype[String]
    type TraceHeader = zio.aws.sfn.model.primitives.TraceHeader.Type
    object Truncated extends zio.prelude.Subtype[Boolean]
    type Truncated = zio.aws.sfn.model.primitives.Truncated.Type
    object URL extends zio.prelude.Subtype[String]
    type URL = zio.aws.sfn.model.primitives.URL.Type
    object UnsignedInteger extends zio.prelude.Subtype[Int]
    type UnsignedInteger = zio.aws.sfn.model.primitives.UnsignedInteger.Type
    object UnsignedLong extends zio.prelude.Subtype[Long]
    type UnsignedLong = zio.aws.sfn.model.primitives.UnsignedLong.Type
    object ValidateStateMachineDefinitionCode
        extends zio.prelude.Subtype[String]
    type ValidateStateMachineDefinitionCode =
      zio.aws.sfn.model.primitives.ValidateStateMachineDefinitionCode.Type
    object ValidateStateMachineDefinitionLocation
        extends zio.prelude.Subtype[String]
    type ValidateStateMachineDefinitionLocation =
      zio.aws.sfn.model.primitives.ValidateStateMachineDefinitionLocation.Type
    object ValidateStateMachineDefinitionMaxResult
        extends zio.prelude.Subtype[Int]
    type ValidateStateMachineDefinitionMaxResult =
      zio.aws.sfn.model.primitives.ValidateStateMachineDefinitionMaxResult.Type
    object ValidateStateMachineDefinitionMessage
        extends zio.prelude.Subtype[String]
    type ValidateStateMachineDefinitionMessage =
      zio.aws.sfn.model.primitives.ValidateStateMachineDefinitionMessage.Type
    object ValidateStateMachineDefinitionTruncated
        extends zio.prelude.Subtype[Boolean]
    type ValidateStateMachineDefinitionTruncated =
      zio.aws.sfn.model.primitives.ValidateStateMachineDefinitionTruncated.Type
    object VersionDescription extends zio.prelude.Subtype[String]
    type VersionDescription =
      zio.aws.sfn.model.primitives.VersionDescription.Type
    object VersionWeight extends zio.prelude.Subtype[Int]
    type VersionWeight = zio.aws.sfn.model.primitives.VersionWeight.Type
  }
  type ActivityList = List[zio.aws.sfn.model.ActivityListItem]
  type ExecutionList = List[zio.aws.sfn.model.ExecutionListItem]
  type HistoryEventList = List[zio.aws.sfn.model.HistoryEvent]
  type LogDestinationList = List[zio.aws.sfn.model.LogDestination]
  type MapRunList = List[zio.aws.sfn.model.MapRunListItem]
  type RoutingConfigurationList =
    List[zio.aws.sfn.model.RoutingConfigurationListItem]
  type StateMachineAliasList = List[zio.aws.sfn.model.StateMachineAliasListItem]
  type StateMachineList = List[zio.aws.sfn.model.StateMachineListItem]
  type StateMachineVersionList =
    List[zio.aws.sfn.model.StateMachineVersionListItem]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.sfn.model.Tag]
  type ValidateStateMachineDefinitionDiagnosticList =
    List[zio.aws.sfn.model.ValidateStateMachineDefinitionDiagnostic]
}

==> zio-aws-sfn_3-5.17.211.1-sources.jar: zio/aws/sfn/model/package.scala <==
package zio.aws.sfn
import zio.prelude.Subtype
import zio.aws.sfn.model.primitives.TagKey
import java.time.Instant
import zio.aws.sfn.model.primitives.ListExecutionsPageToken.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.sfn.model.primitives.Arn.Type
    object BilledDuration extends Subtype[Long]
    type BilledDuration = zio.aws.sfn.model.primitives.BilledDuration.Type
    object BilledMemoryUsed extends Subtype[Long]
    type BilledMemoryUsed = zio.aws.sfn.model.primitives.BilledMemoryUsed.Type
    object ConnectorParameters extends Subtype[String]
    type ConnectorParameters =
      zio.aws.sfn.model.primitives.ConnectorParameters.Type
    object Definition extends Subtype[String]
    type Definition = zio.aws.sfn.model.primitives.Definition.Type
    object Enabled extends Subtype[Boolean]
    type Enabled = zio.aws.sfn.model.primitives.Enabled.Type
    object EventId extends Subtype[Long]
    type EventId = zio.aws.sfn.model.primitives.EventId.Type
    object Identity extends Subtype[String]
    type Identity = zio.aws.sfn.model.primitives.Identity.Type
    object IncludeExecutionData extends Subtype[Boolean]
    type IncludeExecutionData =
      zio.aws.sfn.model.primitives.IncludeExecutionData.Type
    object IncludeExecutionDataGetExecutionHistory extends Subtype[Boolean]
    type IncludeExecutionDataGetExecutionHistory =
      zio.aws.sfn.model.primitives.IncludeExecutionDataGetExecutionHistory.Type
    object IncludedDetails extends Subtype[Boolean]
    type IncludedDetails = zio.aws.sfn.model.primitives.IncludedDetails.Type
    object ListExecutionsPageToken extends Subtype[String]
    type ListExecutionsPageToken =
      zio.aws.sfn.model.primitives.ListExecutionsPageToken.Type
    object Name extends Subtype[String]
    type Name = zio.aws.sfn.model.primitives.Name.Type
    object PageSize extends Subtype[Int]
    type PageSize = zio.aws.sfn.model.primitives.PageSize.Type
    object PageToken extends Subtype[String]
    type PageToken = zio.aws.sfn.model.primitives.PageToken.Type
    object ReverseOrder extends Subtype[Boolean]
    type ReverseOrder = zio.aws.sfn.model.primitives.ReverseOrder.Type
    object SensitiveCause extends Subtype[String]
    type SensitiveCause = zio.aws.sfn.model.primitives.SensitiveCause.Type
    object SensitiveData extends Subtype[String]
    type SensitiveData = zio.aws.sfn.model.primitives.SensitiveData.Type
    object SensitiveDataJobInput extends Subtype[String]
    type SensitiveDataJobInput =
      zio.aws.sfn.model.primitives.SensitiveDataJobInput.Type
    object SensitiveError extends Subtype[String]
    type SensitiveError = zio.aws.sfn.model.primitives.SensitiveError.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.sfn.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.sfn.model.primitives.TagValue.Type
    object TaskToken extends Subtype[String]
    type TaskToken = zio.aws.sfn.model.primitives.TaskToken.Type
    object TimeoutInSeconds extends Subtype[Long]
    type TimeoutInSeconds = zio.aws.sfn.model.primitives.TimeoutInSeconds.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.sfn.model.primitives.Timestamp.Type
    object TraceHeader extends Subtype[String]
    type TraceHeader = zio.aws.sfn.model.primitives.TraceHeader.Type
    object Truncated extends Subtype[Boolean]
    type Truncated = zio.aws.sfn.model.primitives.Truncated.Type
    object UnsignedInteger extends Subtype[Int]
    type UnsignedInteger = zio.aws.sfn.model.primitives.UnsignedInteger.Type
  }
  type ActivityList = List[zio.aws.sfn.model.ActivityListItem]
  type ExecutionList = List[zio.aws.sfn.model.ExecutionListItem]
  type HistoryEventList = List[zio.aws.sfn.model.HistoryEvent]
  type LogDestinationList = List[zio.aws.sfn.model.LogDestination]
  type StateMachineList = List[zio.aws.sfn.model.StateMachineListItem]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.sfn.model.Tag]
}
